package powersoft.beanbox;

import java.awt.Color;
import java.awt.Frame;
import java.awt.Image;
import java.beans.BeanDescriptor;
import java.beans.BeanInfo;
import java.beans.EventSetDescriptor;
import java.beans.FeatureDescriptor;
import java.beans.IntrospectionException;
import java.beans.Introspector;
import java.beans.MethodDescriptor;
import java.beans.ParameterDescriptor;
import java.beans.PropertyDescriptor;
import java.beans.PropertyEditor;
import java.beans.PropertyEditorManager;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.Hashtable;
import java.util.Properties;
import powersoft.powerj.util.Bmp;

public class BeanReader {
   public String _className = null;
   public Class _class = null;
   public BeanInfo _currentBeanInfo = null;
   public BeanInfo _firstBeanInfo = null;
   public BeanInfo[] _additionalBeanInfo = null;
   public BeanDescriptor _currentBeanDescriptor = null;

   public void unloadAll() {
      this._className = null;
      this._class = null;
      this._currentBeanInfo = null;
      this._firstBeanInfo = null;
      this._additionalBeanInfo = null;
      this._currentBeanDescriptor = null;
      System.gc();
   }

   public boolean loadBeanInfo() {
      boolean var1 = true;
      Object var2 = null;
      Object var3 = null;

      try {
         var8 = Class.forName(this._className + "BeanInfo");
      } catch (ClassNotFoundException var7) {
         return false;
      }

      try {
         var3 = var8.newInstance();
      } catch (InstantiationException var5) {
         System.out.println("Couldn't instantiate an instance of " + this._className + "'s BeanInfo class.");
         return false;
      } catch (IllegalAccessException var6) {
         System.out.println("Couldn't instantiate an instance of " + this._className + "'s BeanInfo class.");
         return false;
      }

      if (!(var3 instanceof BeanInfo)) {
         System.out.println(var8 + " is not a java.beans.BeanInfo.");
      } else {
         this._firstBeanInfo = (BeanInfo)var3;
      }

      if (this._firstBeanInfo == null) {
         try {
            this._firstBeanInfo = Introspector.getBeanInfo(this._class);
         } catch (IntrospectionException var4) {
            System.out.println("Couldn't get BeanInfo for " + this._className + ".");
            return false;
         }
      }

      this._additionalBeanInfo = this._firstBeanInfo.getAdditionalBeanInfo();
      this._currentBeanInfo = this._firstBeanInfo;
      this._currentBeanDescriptor = this._currentBeanInfo.getBeanDescriptor();
      return var1;
   }

   public boolean loadClass(String var1) {
      boolean var2 = true;
      this._className = null;
      this._class = null;
      this._currentBeanInfo = null;
      this._firstBeanInfo = null;
      this._additionalBeanInfo = null;
      this._currentBeanDescriptor = null;
      this._className = var1;

      try {
         this._class = Class.forName(this._className);
         return var2;
      } catch (ClassNotFoundException var3) {
         System.out.println("Couldn't find " + this._className + " class.");
         return false;
      }
   }

   public int getPropertyCount() {
      return this._currentBeanInfo.getPropertyDescriptors().length;
   }

   public PropertyDescriptor getPropertyDescriptor(int var1) {
      return this._currentBeanInfo.getPropertyDescriptors()[var1];
   }

   public Class getPropertyType(PropertyDescriptor var1) {
      return var1.getPropertyType();
   }

   public String getPropertyTypeName(PropertyDescriptor var1) {
      return var1.getPropertyType().getName();
   }

   public Method getReadMethod(PropertyDescriptor var1) {
      return var1.getReadMethod();
   }

   public String getReadMethodName(PropertyDescriptor var1) {
      return var1.getReadMethod().getName();
   }

   public Method getWriteMethod(PropertyDescriptor var1) {
      return var1.getWriteMethod();
   }

   public String getWriteMethodName(PropertyDescriptor var1) {
      return var1.getWriteMethod().getName();
   }

   public PropertyEditor getPropertyEditor(PropertyDescriptor var1) {
      PropertyEditor var2 = null;
      Class var3 = var1.getPropertyEditorClass();
      if (var3 != null) {
         try {
            var2 = (PropertyEditor)var3.newInstance();
         } catch (Exception var4) {
            var2 = null;
         }
      }

      if (var2 == null) {
         var2 = PropertyEditorManager.findEditor(var1.getPropertyType());
      }

      return var2;
   }

   public String getPropertyEditorClassName(PropertyEditor var1) {
      Object var2 = null;
      String var3 = null;
      if (var1 != null) {
         Class var4 = var1.getClass();
         if (var4 != null) {
            var3 = var4.getName();
         }
      }

      return var3 == null ? new String("") : var3;
   }

   public int getPropertyEditorType(PropertyEditor var1) {
      if (var1 == null) {
         return -1;
      } else {
         Object var2 = null;
         boolean var3 = false;
         Object var4 = null;

         try {
            var8 = var1.getCustomEditor();
         } catch (Exception var7) {
            var8 = null;
         }

         try {
            var3 = var1.supportsCustomEditor();
         } catch (Exception var6) {
            var3 = false;
         }

         if (var8 != null && var3) {
            return 0;
         } else {
            try {
               var10 = var1.getTags();
            } catch (Exception var5) {
               var10 = null;
            }

            return var10 != null && var10.length > 1 ? 1 : 2;
         }
      }
   }

   public boolean isBound(PropertyDescriptor var1) {
      return var1.isBound();
   }

   public boolean isConstrained(PropertyDescriptor var1) {
      return var1.isConstrained();
   }

   public int getBeanInfoCount() {
      return this._additionalBeanInfo != null ? 1 + this._additionalBeanInfo.length : 1;
   }

   public boolean setCurrentBeanInfo(int var1) {
      if (var1 >= this.getBeanInfoCount()) {
         return false;
      } else {
         BeanInfo var2;
         if (var1 == 0) {
            var2 = null;
         } else {
            var2 = this._additionalBeanInfo[var1 - 1];
         }

         if (var2 == this._currentBeanInfo) {
            return true;
         } else {
            this._currentBeanInfo = var2;
            this._currentBeanDescriptor = this._currentBeanInfo.getBeanDescriptor();
            return true;
         }
      }
   }

   public int getMethodCount() {
      return this._currentBeanInfo.getMethodDescriptors().length;
   }

   public MethodDescriptor getMethodDescriptor(int var1) {
      return this._currentBeanInfo.getMethodDescriptors()[var1];
   }

   public Method getMethod(MethodDescriptor var1) {
      return var1.getMethod();
   }

   public int getEventCount() {
      return this._currentBeanInfo.getEventSetDescriptors().length;
   }

   public EventSetDescriptor getEventSetDescriptor(int var1) {
      return this._currentBeanInfo.getEventSetDescriptors()[var1];
   }

   public MethodDescriptor getListenerMethodDescriptor(EventSetDescriptor var1, int var2) {
      return var1.getListenerMethodDescriptors()[var2];
   }

   public int getListenerMethodCount(EventSetDescriptor var1) {
      return var1.getListenerMethodDescriptors().length;
   }

   public Class getBeanClass() {
      return this._currentBeanDescriptor != null ? this._currentBeanDescriptor.getBeanClass() : this._class;
   }

   public String getBeanClassName() {
      Class var1 = null;
      String var2 = null;
      if (this._currentBeanDescriptor != null) {
         var1 = this._currentBeanDescriptor.getBeanClass();
      }

      if (var1 == null) {
         var1 = this._class;
      }

      if (var1 != null) {
         var2 = var1.getName();
      }

      return var2 == null ? new String("") : var2;
   }

   public int getDefaultEventIndex() {
      return this._currentBeanInfo.getDefaultEventIndex();
   }

   public int getDefaultPropertyIndex() {
      return this._currentBeanInfo.getDefaultPropertyIndex();
   }

   public Class getCustomizerClass() {
      Class var1 = null;
      if (this._currentBeanDescriptor != null) {
         var1 = this._currentBeanDescriptor.getCustomizerClass();
      }

      if (var1 == null) {
         try {
            var1 = Class.forName(this._className + "Customizer");
         } catch (ClassNotFoundException var2) {
            return null;
         }
      }

      return var1;
   }

   public String getCustomizerClassName() {
      Object var1 = null;
      String var2 = null;
      Class var3 = this.getCustomizerClass();
      if (var3 != null) {
         var2 = var3.getName();
      }

      return var2 == null ? new String("") : var2;
   }

   public BeanDescriptor getBeanDescriptor() {
      return this._currentBeanDescriptor;
   }

   public String getAddListenerMethodName(EventSetDescriptor var1) {
      return var1.getAddListenerMethod().getName();
   }

   public Method getAddListenerMethod(EventSetDescriptor var1) {
      return var1.getAddListenerMethod();
   }

   public String getRemoveListenerMethodName(EventSetDescriptor var1) {
      return var1.getRemoveListenerMethod().getName();
   }

   public Method getRemoveListenerMethod(EventSetDescriptor var1) {
      return var1.getRemoveListenerMethod();
   }

   public boolean isUnicast(EventSetDescriptor var1) {
      return var1.isUnicast();
   }

   public Class getListenerTypeClass(EventSetDescriptor var1) {
      return var1.getListenerType();
   }

   public String getListenerTypeClassName(EventSetDescriptor var1) {
      Class var2 = var1.getListenerType();
      String var3 = null;
      if (var2 != null) {
         var3 = var2.getName();
      }

      return var3 == null ? new String("") : var3;
   }

   public int getParameterCount(MethodDescriptor var1) {
      return var1.getParameterDescriptors().length;
   }

   public ParameterDescriptor getParameterDescriptor(MethodDescriptor var1, int var2) {
      return var1.getParameterDescriptors()[var2];
   }

   public String getDisplayName(FeatureDescriptor var1) {
      return var1.getDisplayName();
   }

   public String getName(FeatureDescriptor var1) {
      return var1.getName();
   }

   public String getShortDescription(FeatureDescriptor var1) {
      return var1.getShortDescription();
   }

   public boolean isHidden(FeatureDescriptor var1) {
      return var1.isHidden();
   }

   public boolean isExpert(FeatureDescriptor var1) {
      return var1.isExpert();
   }

   public Class getReturnType(Method var1) {
      return var1.getReturnType();
   }

   public String getReturnTypeName(Method var1) {
      return var1.getReturnType().getName();
   }

   public Class[] getParameterTypes(Method var1) {
      return var1.getParameterTypes();
   }

   public int getParameterTypeCount(Method var1) {
      return var1.getParameterTypes().length;
   }

   public Class getParameterType(Method var1, int var2) {
      return var1.getParameterTypes()[var2];
   }

   public String getParameterTypeName(Class[] var1, int var2) {
      return var1[var2].getName();
   }

   public String getParameterTypeName(Method var1, int var2) {
      return var1.getParameterTypes()[var2].getName();
   }

   public int getExceptionTypeCount(Method var1) {
      return var1.getExceptionTypes().length;
   }

   public Class getExceptionType(Method var1, int var2) {
      return var1.getExceptionTypes()[var2];
   }

   public String getExceptionTypeName(Method var1, int var2) {
      return var1.getExceptionTypes()[var2].getName();
   }

   public Object invoke(Method var1, Object var2, Object[] var3) {
      try {
         return var1.invoke(var2, var3);
      } catch (IllegalAccessException var4) {
         System.out.println("Error invoking the " + var1.getName() + " method of the " + var1.getDeclaringClass().getName() + " class - IllegalAccessException occurred.");
      } catch (IllegalArgumentException var5) {
         System.out.println("Error invoking the " + var1.getName() + " method of the " + var1.getDeclaringClass().getName() + " class - IllegalArgumentException occurred.");
      } catch (InvocationTargetException var6) {
         System.out.println("Error invoking the " + var1.getName() + " method of the " + var1.getDeclaringClass().getName() + " class - InvocationTargetException occurred.");
      }

      return null;
   }

   public String getName(Method var1) {
      return var1.getName();
   }

   public String getSuperclassName(Class var1) {
      return var1.getSuperclass() != null ? var1.getSuperclass().getName() : new String();
   }

   public boolean hasSuperclass(Class var1) {
      return var1.getSuperclass() != null;
   }

   public Method getMethod(Class var1, int var2) {
      return var1.getMethods()[var2];
   }

   public int getMethodCount(Class var1) {
      return var1.getMethods().length;
   }

   public Class getSuperclass(Class var1) {
      return var1.getSuperclass();
   }

   public int getModifiers(Class var1) {
      return var1.getModifiers();
   }

   public String getName(Class var1) {
      return var1.getName();
   }

   public Class getCurrentClass() {
      return this._class;
   }

   public String getClassPath() {
      Properties var1 = System.getProperties();
      return var1 == null ? new String() : var1.getProperty("java.class.path");
   }

   public boolean setClassPath(String var1) {
      Properties var2 = System.getProperties();
      if (var2 == null) {
         return false;
      } else {
         ((Hashtable)var2).remove("java.class.path");
         ((Hashtable)var2).put("java.class.path", var1);
         System.setProperties(var2);
         return true;
      }
   }

   public Image getIcon(int var1) {
      BeanInfo var2 = this._currentBeanInfo;
      if (var2 == null) {
         return null;
      } else {
         switch (var1) {
            case 0:
               return var2.getIcon(1);
            case 1:
               return var2.getIcon(2);
            case 2:
               return var2.getIcon(3);
            case 3:
               return var2.getIcon(4);
            default:
               return null;
         }
      }
   }

   public byte[] getIconAsByteArray(int var1) {
      Image var3 = null;
      BeanInfo var2 = this._currentBeanInfo;
      if (var2 == null) {
         return null;
      } else {
         switch (var1) {
            case 0:
               var3 = var2.getIcon(1);
               if (var3 == null) {
                  var3 = var2.getIcon(3);
               }
               break;
            case 1:
               var3 = var2.getIcon(2);
               if (var3 == null) {
                  var3 = var2.getIcon(4);
               }
         }

         byte[] var4;
         try {
            var4 = Bmp.createBmp(var3, Color.lightGray);
         } catch (Exception var5) {
            var4 = null;
         }

         return var4;
      }
   }

   public boolean isSerializable() {
      Object var1 = null;
      boolean var3 = false;
      String var4 = new String("java.io.Serializable");
      Class[] var5 = this._class.getInterfaces();

      for(int var2 = 0; var2 < var5.length; ++var2) {
         if (var5[var2].getName().compareTo(var4) == 0) {
            var3 = true;
            break;
         }
      }

      return var3;
   }

   public boolean hasIcon(int var1) {
      if (this._currentBeanInfo == null) {
         return false;
      } else {
         Image var2 = null;
         switch (var1) {
            case 0:
               var2 = this._currentBeanInfo.getIcon(1);
               break;
            case 1:
               var2 = this._currentBeanInfo.getIcon(2);
               break;
            case 2:
               var2 = this._currentBeanInfo.getIcon(3);
               break;
            case 3:
               var2 = this._currentBeanInfo.getIcon(4);
         }

         return var2 != null;
      }
   }

   public boolean setIconImage(int var1, Frame var2) {
      if (this._currentBeanInfo == null) {
         return false;
      } else {
         Image var3 = null;
         switch (var1) {
            case 0:
               var3 = this._currentBeanInfo.getIcon(1);
               break;
            case 1:
               var3 = this._currentBeanInfo.getIcon(2);
               break;
            case 2:
               var3 = this._currentBeanInfo.getIcon(3);
               break;
            case 3:
               var3 = this._currentBeanInfo.getIcon(4);
         }

         if (var3 == null) {
            return false;
         } else {
            var2.setIconImage(var3);
            return true;
         }
      }
   }
}
